# napalm_netonix
NAPALM module for Netonix WISP switches

uses [python_napalm_api](https://github.com/shrank/python_netonix_api)

## Implemented APIs
 - open
 - close
 - is_alive
 - get_mac_address_table
 - get_config
 - load_replace_candidate
 - load_merge_candidate
 - compare_config
 - commit_config

*partially implemented:*
 - get_interfaces
 - get_interfaces_counters
